skosprovider_rdf
================

An implementation of the skosprovider_ interface that supports various RDF
serialisations through RDFLib.

.. image:: https://img.shields.io/pypi/v/skosprovider_rdf.svg
        :target: https://pypi.python.org/pypi/skosprovider_rdf
.. image:: https://readthedocs.org/projects/skosprovider_rdf/badge/?version=latest
        :target: https://readthedocs.org/projects/skosprovider_rdf/?badge=latest
.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.7002514.svg
        :target: https://doi.org/10.5281/zenodo.7002514
.. image:: https://app.travis-ci.com/OnroerendErfgoed/skosprovider_rdf.svg?branch=develop
        :target: https://app.travis-ci.com/OnroerendErfgoed/skosprovider_rdf
.. image:: https://img.shields.io/coveralls/OnroerendErfgoed/skosprovider_rdf.svg
        :target: https://coveralls.io/r/OnroerendErfgoed/skosprovider_rdf
.. image:: https://scrutinizer-ci.com/g/OnroerendErfgoed/skosprovider_rdf/badges/quality-score.png?b=master
        :target: https://scrutinizer-ci.com/g/OnroerendErfgoed/skosprovider_rdf/?branch=master

.. _skosprovider: https://github.com/OnroerendErfgoed/skosprovider

